You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ambari.apache.org by nc...@apache.org on 2016/10/19 16:47:27 UTC

[16/50] [abbrv] ambari git commit: AMBARI-18573. Migration to Bootstrap3 framework (akovalenko)

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/controls_service_config_textfield_with_unit.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/controls_service_config_textfield_with_unit.hbs b/ambari-web/app/templates/wizard/controls_service_config_textfield_with_unit.hbs
index 557ee09..ef20ccd 100644
--- a/ambari-web/app/templates/wizard/controls_service_config_textfield_with_unit.hbs
+++ b/ambari-web/app/templates/wizard/controls_service_config_textfield_with_unit.hbs
@@ -17,4 +17,4 @@
 }}
 
 {{view App.ServiceConfigTextField serviceConfigBinding="view.serviceConfig" isPopoverEnabled="false"}}
-<span class="add-on">{{view.serviceConfig.unit}}</span>
+<span class="input-group-addon">{{view.serviceConfig.unit}}</span>

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step0.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step0.hbs b/ambari-web/app/templates/wizard/step0.hbs
index 4b1cc49..38f9269 100644
--- a/ambari-web/app/templates/wizard/step0.hbs
+++ b/ambari-web/app/templates/wizard/step0.hbs
@@ -20,7 +20,7 @@
   <p class="alert alert-info">
     {{t installer.step0.body}}
   </p>
-  <div {{bindAttr class="view.onError:error :control-group"}}>
+  <div {{bindAttr class="view.onError:has-error :form-group"}}>
     <label class="control-label" for="cluster-name">{{t installer.step0.clusterName}}
       <a href="javascript:void(null)"
          rel="popover"
@@ -28,9 +28,11 @@
         data-content="installer.step0.clusterName.tooltip.content"}}>{{t common.learnMore}}</a>
     </label>
 
-    <div class="controls">
-      {{view App.WizardStep0ViewClusterNameInput id="cluster-name" valueBinding="content.cluster.name" placeholder="cluster name" target="controller"}}
-      <p class="help-inline">{{clusterNameError}}</p>
+    <div>
+      {{view App.WizardStep0ViewClusterNameInput id="cluster-name" valueBinding="content.cluster.name" placeholder="cluster name" target="controller" classNames="col-sm-3"}}
+      {{#if clusterNameError}}
+        <p class="help-block validation-block col-sm-9">{{clusterNameError}}</p>
+      {{/if}}
     </div>
   </div>
 

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step1.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step1.hbs b/ambari-web/app/templates/wizard/step1.hbs
index 7c5bc21..f78f01c 100644
--- a/ambari-web/app/templates/wizard/step1.hbs
+++ b/ambari-web/app/templates/wizard/step1.hbs
@@ -20,56 +20,48 @@
   <p class="alert alert-info">{{t installer.step1.body}}</p>
 
   {{! left tabs }}
-  <div class="row-fluid">
-    <div class="span2">
-      <ul class="nav nav-tabs tabs-left">
+  <div class="row">
+    <div class="col-md-2">
+      <ul class="nav nav-tabs nav-stacked nav-tabs-left">
         {{#each stack in availableStackTypes}}
           <li {{bindAttr class="stack.isSelected:active"}}><a {{action "selectRepoInList" stack target="controller"}} href="#">{{stack.stackName}}</a></li>
         {{/each}}
       </ul>
     </div>
 
-    <div class="span10">
-      <div class="tab-content">
-        <div class="accordion-group details-panel">
-          <div class="accordion-body">
-            <div class="accordion-inner">
-              <div class="row-fluid">
-                <div class="version-info">
-                  <div class="btn-group">
-                    <button type="button" data-toggle="dropdown" class="btn dropdown-toggle btn-info">{{controller.selectedStack.displayName}} <span class="caret"></span></button>
-                    <ul class="dropdown-menu">
-                      {{#each stack in selectedStackType.stacks}}
-                        <li>
-                          {{!view view.stackRadioButton stackBinding="stack"}}
-                          <a href="#" {{action "changeVersion" stack target="controller"}}>{{stack.displayName}}
-                            {{#if stack.stackDefault}}
-                              ({{t installer.step1.changeVersion.defaultVersion}})
-                            {{/if}}
-                          </a>
-                        </li>
-                      {{/each}}
-                      <li><a href="#" {{action "uploadVdf" target="controller"}}>{{t installer.step1.addVersion}} ...</a></li>
-                    </ul>
-                  </div>
-                </div>
-                <div class="version-contents-section">
-                  {{#unless servicesForSelectedStack}}
-                    <div class="alert alert-info" role="alert">{{t installer.step1.useLocalRepo.infoForm.content.empty}}</div>
-                  {{/unless}}
-                  <table class="table table-striped table-condensed">
-                  {{#each service in servicesForSelectedStack}}
-                    <tr>
-                      <td class="span4">{{service.displayName}}</td>
-                      <td class="span8">{{service.latestVersion}}</td>
-                    </tr>
-                  {{/each}}
-                  </table>
-                </div>
-              </div>
-            </div>
+    <div class="col-md-10">
+      <div class="details-panel">
+        <div class="version-info">
+          <div class="btn-group">
+            <button type="button" data-toggle="dropdown" class="btn dropdown-toggle btn-info">{{controller.selectedStack.displayName}} <span class="caret"></span></button>
+            <ul class="dropdown-menu">
+              {{#each stack in selectedStackType.stacks}}
+                <li>
+                  {{!view view.stackRadioButton stackBinding="stack"}}
+                  <a href="#" {{action "changeVersion" stack target="controller"}}>{{stack.displayName}}
+                    {{#if stack.stackDefault}}
+                      ({{t installer.step1.changeVersion.defaultVersion}})
+                    {{/if}}
+                  </a>
+                </li>
+              {{/each}}
+              <li><a href="#" {{action "uploadVdf" target="controller"}}>{{t installer.step1.addVersion}} ...</a></li>
+            </ul>
           </div>
         </div>
+        <div class="version-contents-section">
+          {{#unless servicesForSelectedStack}}
+            <div class="alert alert-info" role="alert">{{t installer.step1.useLocalRepo.infoForm.content.empty}}</div>
+          {{/unless}}
+          <table class="table table-striped table-condensed">
+          {{#each service in servicesForSelectedStack}}
+            <tr>
+              <td class="col-md-4">{{service.displayName}}</td>
+              <td class="col-md-8">{{service.latestVersion}}</td>
+            </tr>
+          {{/each}}
+          </table>
+        </div>
       </div>
     </div>
   </div>
@@ -92,32 +84,31 @@
   {{else}}
   <form id="repoVersionInfoForm" class="form-horizontal" role="form" name="localVersionInfoForm" novalidate>
 
-    <div class="accordion-group repos-panel">
-      <div class="accordion-heading">
+    <div class="panel panel-default repos-panel">
+      <div class="panel-heading">
         <p>{{t common.repositories}}</p>
       </div>
-      <div class="accordion-body version-contents-body">
-        <div class="accordion-inner">
+      <div class="panel-body version-contents-body">
           <div class="alert alert-info" role="alert">{{t installer.step1.useLocalRepo.infoForm.alert.baseUrl}}</div>
           {{#if view.showWarning}}
-            <div class="alert">{{t installer.step1.attentionNeeded}}</div>
+            <div class="alert alert-warning">{{t installer.step1.attentionNeeded}}</div>
           {{/if}}
 
           {{! OSes and Repositories }}
-          <div class="clearfix repo-table-title row-fluid">
-            <div class="span2"><label>{{t common.os}}</label></div>
-            <div class="span9">
-              <div class="span3"><label>{{t common.name}}</label></div>
-              <div class="span1"></div>
-              <div class="span8"><label>{{t installer.step1.advancedRepo.localRepo.column.baseUrl}}</label></div>
+          <div class="clearfix repo-table-title row">
+            <div class="col-md-2"><label>{{t common.os}}</label></div>
+            <div class="col-md-9">
+              <div class="col-md-3"><label>{{t common.name}}</label></div>
+              <div class="col-md-1"></div>
+              <div class="col-md-8"><label>{{t installer.step1.advancedRepo.localRepo.column.baseUrl}}</label></div>
             </div>
-            <div class="span1">
+            <div class="col-md-1">
               {{! Add OS }}
               <div class="add-os-button btn-group pull-right">
                 <button
-                  type="button" {{bindAttr data-original-title="view.addOsButtonTooltip"  class=":btn :dropdown-toggle :add-os-button view.isAddOsButtonDisabled:disabled"}}
+                  type="button" {{bindAttr data-original-title="view.addOsButtonTooltip"  class=":btn :btn-default :dropdown-toggle :add-os-button view.isAddOsButtonDisabled:disabled"}}
                   data-toggle="dropdown">
-                  <i class="icon-plus"></i> {{t common.add}} &nbsp;<span class="caret"></span>
+                  <i class="glyphicon glyphicon-plus"></i> {{t common.add}} &nbsp;<span class="caret"></span>
                 </button>
                 <ul class="dropdown-menu">
                   {{#each operatingSystem in selectedStack.operatingSystems}}
@@ -133,23 +124,23 @@
 
           {{#each operatingSystem in selectedStack.operatingSystems}}
             {{#if operatingSystem.isSelected}}
-              <div {{bindAttr class=":clearfix :row-fluid :border-bottom operatingSystem.osType"}}>
-                <div class="span2 os-type-label">
+              <div {{bindAttr class=":clearfix :row :border-bottom operatingSystem.osType"}}>
+                <div class="col-md-2 os-type-label">
                   <label>{{operatingSystem.osType}}</label>
                 </div>
-                <div class="span9 repo-name-url">
+                <div class="col-md-9 repo-name-url">
                   {{#each repository in operatingSystem.repositories}}
                     <div {{bindAttr class=":clearfix :repo-name-url-inner repository.repoName"}}>
-                      <div class="span3">
+                      <div class="col-md-3">
                         <label class="repo-name-label control-label">{{repository.repoId}}</label>
                       </div>
-                      <div class="validation-td span1">
+                      <div class="validation-td col-md-1">
                         {{#if repository.validation}}
                           {{view view.popoverView repositoryBinding="repository"}}
                         {{/if}}
                       </div>
-                      <div {{bindAttr class=":span8 :repo-url repository.invalidFormatError:textfield-error repository.invalidError:textfield-error"}}>
-                        {{view Ember.TextField placeholderBinding="repository.placeholder" valueBinding="repository.baseUrl" disabledBinding="controller.selectedStack.useRedhatSatellite"}}
+                      <div {{bindAttr class=":col-md-8 :repo-url repository.invalidFormatError:textfield-error repository.invalidError:textfield-error"}}>
+                        {{view Ember.TextField placeholderBinding="repository.placeholder" valueBinding="repository.baseUrl" disabledBinding="controller.selectedStack.useRedhatSatellite" classNames="form-control"}}
                           {{#if controller.selectedStack.usePublicRepo}}
                             {{#if repository.undo}}
                               <i class="icon-undo" data-toggle="tooltip"
@@ -169,19 +160,19 @@
                     </div>
                   {{/each}}
                 </div>
-                <div {{bindAttr class=":span1 :remove-icon controller.selectedStack.useRedhatSatellite:disabled"}} {{action "removeOS" operatingSystem target="controller"}}>
-                  <i class="icon-minus"></i>{{t common.remove}}</div>
+                <div {{bindAttr class=":col-md-1 :remove-icon controller.selectedStack.useRedhatSatellite:disabled"}} {{action "removeOS" operatingSystem target="controller"}}>
+                  <i class="glyphicon glyphicon-minus"></i>{{t common.remove}}</div>
               </div>
             {{/if}}
           {{/each}}
           {{! OSes and Repositories END }}
 
           {{! Skip Repository Base URL validation }}
-          <div id="skip-validation" {{bindAttr class="controller.selectedStack.useRedhatSatellite:disabled"}}>
+          <div id="skip-validation" {{bindAttr class="controller.selectedStack.useRedhatSatellite:disabled :checkbox"}}>
             <label>
-              {{view Ember.Checkbox checkedBinding="skipValidationChecked" disabledBinding="controller.selectedStack.useRedhatSatellite" class="checkbox"}}
+              {{view Ember.Checkbox checkedBinding="skipValidationChecked" disabledBinding="controller.selectedStack.useRedhatSatellite"}}
               <span {{bindAttr class="controller.selectedStack.useRedhatSatellite:disabled"}}>{{t installer.step1.advancedRepo.skipValidation.message}}</span>
-              <i class="icon-question-sign" rel="skip-validation-tooltip"
+              <i class="glyphicon glyphicon-question-sign" rel="skip-validation-tooltip"
                  data-toggle="tooltip" {{translateAttr title="installer.step1.advancedRepo.skipValidation.tooltip"}}>
               </i>
             </label>
@@ -189,28 +180,27 @@
           {{! Skip Repository Base URL validation END }}
 
           {{! Use RedHat Satellite/Spacewalk }}
-          <div id="use-redhat">
+          <div id="use-redhat" class="checkbox">
             <label>
               {{view view.redhatCheckBoxView}}
               <span {{bindAttr class=":redhat-label controller.selectedStack.usePublicRepo:disabled" data-original-title="view.redhatDisabledTooltip"}}>{{t installer.step1.advancedRepo.useRedhatSatellite.message}}</span>
-              <i class="icon-question-sign" rel="use-redhat-tooltip"
+              <i class="glyphicon glyphicon-question-sign" rel="use-redhat-tooltip"
                  data-toggle="tooltip" {{translateAttr title="installer.step1.advancedRepo.useRedhatSatellite.tooltip"}}>
               </i>
             </label>
           </div>
           {{! Use RedHat Satellite/Spacewalk END }}
-        </div>
       </div>
     </div>
   </form>
   {{/if}}
   {{#if view.invalidUrlExist}}
-    <div class="alert">
+    <div class="alert alert-warning">
       {{t installer.step1.invalidURLAttention}}
       <a href="javascript:void(null)" {{action "retryRepoUrls" target="view"}}>{{t installer.step1.retryRepoUrls}}</a>
     </div>
   {{/if}}
-  <button type="button" class="btn pull-left installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
+  <button type="button" class="btn btn-default pull-left installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
     &larr; {{t common.back}}
     {{#if App.router.backBtnClickInProgress}}
       {{view App.SpinnerView tagName="span" classNames="service-button-spinner"}}
@@ -222,4 +212,4 @@
     {{/if}}
     {{t common.next}} &rarr;
   </button>
-</div>
\ No newline at end of file
+</div>

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step1/vdf_upload.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step1/vdf_upload.hbs b/ambari-web/app/templates/wizard/step1/vdf_upload.hbs
index 33fe6c8..48902de 100644
--- a/ambari-web/app/templates/wizard/step1/vdf_upload.hbs
+++ b/ambari-web/app/templates/wizard/step1/vdf_upload.hbs
@@ -16,26 +16,26 @@
 * limitations under the License.
 }}
 
-<div class="clearfix register-version-options row-fluid">
-  {{#view "view.uploadFileView"}}
-    <div class="span5 option-radio-button">
+<div class="clearfix register-version-options row">
+  {{#view "view.uploadFileView" class="col-md-12"}}
+    <div class="col-md-5 option-radio-button">
       <label class="local-option-label radio">
         {{view view.uploadFileRadioButton}} {{t installer.step1.useLocalRepo.uploadFile}}
       </label>
     </div>
-    <div class="span12">
+    <div class="col-md-12">
       {{#if view.isFileApi}}
         {{view view.fileInputView}}
       {{/if}}
     </div>
   {{/view}}
-  {{#view "view.enterUrlView"}}
-    <div class="option-radio-button">
+  {{#view "view.enterUrlView" class="col-md-12"}}
+    <div class="option-radio-button col-md-12">
       <label class="local-option-label radio">
         {{view view.enterUrlRadioButton}} {{t installer.step1.useLocalRepo.enterUrl}}
       </label>
     </div>
-    <div class="span12 vdf-url">
+    <div class="col-md-12 vdf-url">
       <div {{bindAttr class="optionsToSelect.useLocalRepo.enterUrl.name optionsToSelect.useLocalRepo.enterUrl.url.hasError:has-error"}}>
         {{view view.enterUrlField class="input-block-level" valueBinding="optionsToSelect.useLocalRepo.enterUrl.url" placeholderBinding="optionsToSelect.useLocalRepo.enterUrl.placeholder"}}
       </div>

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step1_addLocalRepository.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step1_addLocalRepository.hbs b/ambari-web/app/templates/wizard/step1_addLocalRepository.hbs
index dcc3598..d701bf8 100644
--- a/ambari-web/app/templates/wizard/step1_addLocalRepository.hbs
+++ b/ambari-web/app/templates/wizard/step1_addLocalRepository.hbs
@@ -18,39 +18,33 @@
   <form class="form-horizontal" id="addLocalRepositoryPopup" autocomplete="off">
     <div class="each-row">
       <label class="control-label">{{t installer.step1.advancedRepo.localRepo.label.os}}</label>
-      <div class="controls">
-        <div class="btn-group">
-				  <a class="btn dropdown-toggle" data-toggle="dropdown" href="#">
-				    {{view.selectedOS.osType}}
-				    <span class="caret"></span>
-				  </a>
-				  <ul class="dropdown-menu">
-  				  {{#each os in view.oses}}
-					    <li>
-  					    <a href="#" {{action selectOS os target="view"}}>
-                  {{os.osType}}
-                </a>
-              </li>
-				    {{/each}}
-				  </ul>
-				</div>
+      <div class="btn-group">
+        <a class="btn btn-default dropdown-toggle" data-toggle="dropdown" href="#">
+          {{view.selectedOS.osType}}
+          <span class="caret"></span>
+        </a>
+        <ul class="dropdown-menu">
+          {{#each os in view.oses}}
+            <li>
+              <a href="#" {{action selectOS os target="view"}}>
+                {{os.osType}}
+              </a>
+            </li>
+          {{/each}}
+        </ul>
       </div>
     </div>
     <div class="each-row">
       <label class="control-label">{{t installer.step1.advancedRepo.localRepo.label.baseUrl}}</label>
-      <div class="controls">
-        {{view Em.TextField valueBinding="view.enteredUrl" classNames="span6"}}
-      </div>
+      {{view Em.TextField valueBinding="view.enteredUrl" classNames="col-md-6"}}
     </div>
     <div class="each-row">
       <label class="control-label">{{t installer.step1.advancedRepo.localRepo.label.stack}}</label>
-      <div class="controls">
-        {{view.stackName}}
-      </div>
+      {{view.stackName}}
     </div>
     <div style="height:100px;"></div>
     {{#if view.errorMessage}}
-	    <div class="alert">
+	    <div class="alert alert-warning">
 			  <strong>{{t common.warning}}</strong>  {{view.errorMessage}}
 			</div>
 	  {{else}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step2.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step2.hbs b/ambari-web/app/templates/wizard/step2.hbs
index 42db6cc..45927a3 100644
--- a/ambari-web/app/templates/wizard/step2.hbs
+++ b/ambari-web/app/templates/wizard/step2.hbs
@@ -22,9 +22,9 @@
   <p class="alert alert-info">{{t installer.step2.body}}</p>
 
   <div id="targetHosts">
-    <h5>{{t installer.step2.targetHosts}}</h5>
+    <strong>{{t installer.step2.targetHosts}}</strong>
 
-    <div {{bindAttr class="hostsError:error :control-group :target-hosts-input"}}>
+    <div {{bindAttr class="hostsError:has-error :form-group :target-hosts-input"}}>
       <p>{{t installer.step2.targetHosts.info}}. {{t installer.step2.orUse}}
         <a href="javascript:void(null)"
            rel="popover"
@@ -33,11 +33,14 @@
         </a>
       </p>
 
-      <div class="controls">
-        {{view Ember.TextArea id="host-names" class="span6" valueBinding="content.installOptions.hostNames" rows="5"
-        placeholder="host names"}}
+      <div class="row">
+        <div class="col-md-6">
+          {{view Ember.TextArea id="host-names" class="form-control" valueBinding="content.installOptions.hostNames" rows="5"
+          placeholder="host names"}}
+        </div>
+        <div class="clearfix"></div>
         {{#if hostsError}}
-          <p class="help-inline">{{hostsError}}</p>
+          <p class="help-block validation-block col-md-8">{{hostsError}}</p>
         {{/if}}
       </div>
     </div>
@@ -45,74 +48,93 @@
 
   <div id="hostConnectivity">
     <div class="ambari-agents">
-      <h5>{{t installer.step2.sshKey}}</h5>
-
-      <label class="radio">
-        {{view view.providingSSHKeyRadioButton}}
-        {{#if useSSH}}
-          {{t installer.step2.useSsh.provide}}
-          <a href="javascript:void(null)"
-             rel="popover"
-            {{translateAttr title="installer.step2.useSsh.tooltip.title" data-content="installer.step2.useSsh.tooltip.content"}}>
-            {{t installer.step2.useSsh.tooltip.title}}</a>
-          {{t installer.step2.useSsh.provide_id_rsa}}
-        {{else}}
-          {{t installer.step2.install.perform}}
-          <a href="javascript:void(null)"
-             rel="popover"
-            {{translateAttr title="installer.step2.automaticInstall.tooltip.title" data-content="installer.step2.automaticInstall.tooltip.content"}}>
-            {{t installer.step2.automaticInstall.tooltip.title}}</a>
-          {{t installer.step2.install.perform_on_hosts}}
-        {{/if}}
-      </label>
+      <strong>{{t installer.step2.sshKey}}</strong>
+
+      <div class="radio">
+        <label>
+          {{view view.providingSSHKeyRadioButton}}
+          {{#if useSSH}}
+            {{t installer.step2.useSsh.provide}}
+            <a href="javascript:void(null)"
+               rel="popover"
+              {{translateAttr title="installer.step2.useSsh.tooltip.title" data-content="installer.step2.useSsh.tooltip.content"}}>
+              {{t installer.step2.useSsh.tooltip.title}}</a>
+            {{t installer.step2.useSsh.provide_id_rsa}}
+          {{else}}
+            {{t installer.step2.install.perform}}
+            <a href="javascript:void(null)"
+               rel="popover"
+              {{translateAttr title="installer.step2.automaticInstall.tooltip.title" data-content="installer.step2.automaticInstall.tooltip.content"}}>
+              {{t installer.step2.automaticInstall.tooltip.title}}</a>
+            {{t installer.step2.install.perform_on_hosts}}
+          {{/if}}
+        </label>
+      </div>
 
       {{#if useSSH}}
         <div class="ssh-key-input">
           {{#if view.isFileApi}}
-            {{view App.SshKeyFileUploader disabledBinding="view.sshKeyState"}}
+            <div class="form-group">
+              {{view App.SshKeyFileUploader disabledBinding="view.sshKeyState"}}
+            </div>
           {{/if}}
-          <div {{bindAttr class="sshKeyError:error :controls :control-group"}}>
-            {{view Ember.TextArea class="span6" rows="3" id="sshKey"
-            placeholder="ssh private key" disabledBinding="view.sshKeyState" valueBinding="content.installOptions.sshKey"}}
+          <div {{bindAttr class="sshKeyError:has-error :form-group :row"}}>
+            <div class="col-md-6">
+              {{view Ember.TextArea class="form-control" rows="3" id="sshKey"
+              placeholder="ssh private key" disabledBinding="view.sshKeyState" valueBinding="content.installOptions.sshKey"}}
+            </div>
+            <div class="clearfix"></div>
             {{#if sshKeyError}}
-              <span class="help-inline">{{sshKeyError}}</span>
+              <span class="help-block validation-block col-md-8">{{sshKeyError}}</span>
             {{/if}}
           </div>
-          <div class="row-fluid">
-            <label rel="tooltip" {{translateAttr title="installer.step2.sshUser.toolTip"}} class="ssh-user pull-left span4">
+          <div class="row">
+            <span rel="tooltip" {{translateAttr title="installer.step2.sshUser.toolTip"}} class="ssh-user col-md-4">
               {{t installer.step2.sshUser}}
-            </label>
+            </span>
 
-            <div {{bindAttr class="sshUserError:error :control-group"}}>
-              {{view view.textFieldView valueBinding="content.installOptions.sshUser" isEnabledBinding="content.installOptions.useSsh"}}
-              {{#if sshUserError}}
-                <span class="help-inline">{{sshUserError}}</span>
-              {{/if}}
+            <div {{bindAttr class="sshUserError:has-error :form-group :col-md-8"}}>
+              <div class="row">
+                <div class="col-md-4">
+                  {{view view.textFieldView valueBinding="content.installOptions.sshUser" isEnabledBinding="content.installOptions.useSsh" classNames="form-control"}}
+                </div>
+                {{#if sshUserError}}
+                  <span class="help-block validation-block col-md-8 help-inline">{{sshUserError}}</span>
+                {{/if}}
+              </div>
             </div>
           </div>
-           <div class="row-fluid">
-                <label rel="tooltip" {{translateAttr title="installer.step2.sshPort.toolTip"}} class="ssh-port pull-left span4">
+           <div class="row">
+                <span rel="tooltip" {{translateAttr title="installer.step2.sshPort.toolTip"}} class="ssh-port col-md-4">
                     {{t installer.step2.sshPort}}
-                </label>
-
-                <div {{bindAttr class="sshPortError:error :control-group"}}>
-                    {{view view.textFieldView valueBinding="content.installOptions.sshPort" isEnabledBinding="content.installOptions.useSsh" }}
-                    {{#if sshPortError}}
-                        <span class="help-inline">{{sshPortError}}</span>
-                    {{/if}}
+                </span>
+
+                <div {{bindAttr class="sshPortError:has-error :form-group :col-md-8"}}>
+                    <div class="row">
+                      <div class="col-md-4">
+                        {{view view.textFieldView valueBinding="content.installOptions.sshPort" isEnabledBinding="content.installOptions.useSsh" classNames="form-control"}}
+                      </div>
+                      {{#if sshPortError}}
+                          <span class="help-block validation-block col-md-8 help-inline">{{sshPortError}}</span>
+                      {{/if}}
+                    </div>
                 </div>
            </div>
           {{#if App.supports.customizeAgentUserAccount}}
-            <div class="row-fluid">
-              <label rel="tooltip" {{translateAttr title="installer.step2.agentUser.toolTip"}} class="ssh-user pull-left span4">
+            <div class="row">
+              <span rel="tooltip" {{translateAttr title="installer.step2.agentUser.toolTip"}} class="ssh-user col-md-4">
                 {{t installer.step2.agentUser}}
-              </label>
-
-              <div {{bindAttr class="agentUserError:error :control-group"}}>
-                {{view view.textFieldView valueBinding="content.installOptions.agentUser" isEnabledBinding="content.installOptions.useSsh"}}
-                {{#if agentUserError}}
-                  <span class="help-inline">{{agentUserError}}</span>
-                {{/if}}
+              </span>
+
+              <div {{bindAttr class="agentUserError:has-error :form-group :col-md-8"}}>
+                <div class="row">
+                  <div class="col-md-4">
+                    {{view view.textFieldView valueBinding="content.installOptions.agentUser" isEnabledBinding="content.installOptions.useSsh" classNames="form-control"}}
+                  </div>
+                  {{#if agentUserError}}
+                    <span class="help-block validation-block col-md-8 help-inline">{{agentUserError}}</span>
+                  {{/if}}
+                </div>
               </div>
             </div>
           {{/if}}
@@ -120,32 +142,33 @@
         </div>
       {{/if}}
 
-      <label class="radio">
-        {{view view.manualRegistrationRadioButton}}
-        {{t installer.step2.install.perform}}
-        {{#if useSSH}}
-          <a href="javascript:void(null)"
-             rel="popover"
-            {{translateAttr title="installer.step2.manualInstall.tooltip.title" data-content="installer.step2.manualInstall.tooltip.content"}}>
-            {{t installer.step2.manualInstall.tooltip.title}}</a>
-        {{else}}
-          <a href="javascript:void(null)"
-             rel="popover"
-            {{translateAttr title="installer.step2.manualInstall.tooltip.title" data-content="installer.step2.manualInstall.tooltip.content_no_ssh"}}>
-            {{t installer.step2.manualInstall.tooltip.title}}</a>
-        {{/if}}
-        {{t installer.step2.install.perform_on_hosts}}
-        {{#if useSSH}}
-          {{t installer.step2.install.without_ssh}}
-        {{/if}}
-      </label>
-
+      <div class="radio">
+        <label>
+          {{view view.manualRegistrationRadioButton}}
+          {{t installer.step2.install.perform}}
+          {{#if useSSH}}
+            <a href="javascript:void(null)"
+               rel="popover"
+              {{translateAttr title="installer.step2.manualInstall.tooltip.title" data-content="installer.step2.manualInstall.tooltip.content"}}>
+              {{t installer.step2.manualInstall.tooltip.title}}</a>
+          {{else}}
+            <a href="javascript:void(null)"
+               rel="popover"
+              {{translateAttr title="installer.step2.manualInstall.tooltip.title" data-content="installer.step2.manualInstall.tooltip.content_no_ssh"}}>
+              {{t installer.step2.manualInstall.tooltip.title}}</a>
+          {{/if}}
+          {{t installer.step2.install.perform_on_hosts}}
+          {{#if useSSH}}
+            {{t installer.step2.install.without_ssh}}
+          {{/if}}
+        </label>
+      </div>
     </div>
   </div>
 
   <div class="btn-area">
     {{#unless view.parentView.controller.hideBackButton}}
-      <button class="btn pull-left installer-back-btn" {{action back}} {{bindAttr disabled="App.router.btnClickInProgress"}}>
+      <button class="btn btn-default pull-left installer-back-btn" {{action back}} {{bindAttr disabled="App.router.btnClickInProgress"}}>
         &larr; {{t common.back}}
         {{#if App.router.backBtnClickInProgress}}
           {{view App.SpinnerView tagName="span" classNames="service-button-spinner"}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step3.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step3.hbs b/ambari-web/app/templates/wizard/step3.hbs
index f5648e1..7255528 100644
--- a/ambari-web/app/templates/wizard/step3.hbs
+++ b/ambari-web/app/templates/wizard/step3.hbs
@@ -26,13 +26,13 @@
       <div class="button-section">
         {{#unless isBackDisabled}}
           <button class="btn btn-primary step3-remove-selected-btn" {{bindAttr disabled="view.noHostsSelected"}}
-            {{action removeSelectedHosts target="controller" }}><i class="icon-trash icon-white"></i>
+            {{action removeSelectedHosts target="controller" }}><i class="glyphicon glyphicon-trash glyphicon-white"></i>
             {{t installer.step3.removeSelected}}
           </button>
         {{/unless}}
         {{#unless isRetryDisabled}}
           <a class="btn btn-primary decommission"
-             href="#" {{action retrySelectedHosts target="view"}}><i class="icon-repeat icon-white"></i>
+             href="#" {{action retrySelectedHosts target="view"}}><i class="glyphicon glyphicon-repeat glyphicon-white"></i>
             {{t installer.step3.retryFailed}}
           </a>
         {{/unless}}
@@ -62,12 +62,12 @@
           <th class="tinyspan">
             {{view Ember.Checkbox checkedBinding="view.pageChecked"}}
           </th>
-          <th class="span5">{{t common.host}}</th>
+          <th class="col-md-5">{{t common.host}}</th>
           <!-- retrieved from local storage initially -->
-          <th class="span2">{{t common.progress}}</th>
-          <th class="span2">{{t common.status}}</th>
+          <th class="col-md-2">{{t common.progress}}</th>
+          <th class="col-md-2">{{t common.status}}</th>
           <!-- given by the parsing function that parses data from bootstrap call, dynamically assign the color -->
-          <th class="span2">{{t common.action}}</th>
+          <th class="col-md-2">{{t common.action}}</th>
           <!-- trash icon -->
           <!-- retry icon -->
         </tr>
@@ -83,8 +83,8 @@
                 <span title="{{unbound host.name}}" class="trim_hostname">{{host.name}}</span>
               </td>
               <td class="step3-table-progress">
-                <div {{bindAttr class="host.bootBarColor host.isBootDone::progress-striped host.isBootDone::active :progress"}}>
-                  <div class="bar" style="width:100%">
+                <div class="progress">
+                  <div {{bindAttr class="host.bootBarColor host.isBootDone::progress-bar-striped host.isBootDone::active :progress-bar"}} style="width:100%">
                   </div>
                 </div>
               </td>
@@ -93,7 +93,7 @@
                    data-toggle="modal" {{action hostLogPopup host target="controller"}}><span {{bindAttr class="host.bootStatusColor"}}>{{host.bootStatusForDisplay}}</span></a>
               </td>
               <td class="step3-table-action">
-                <a class="btn btn-mini" {{action remove target="view"}}{{bindAttr disabled="isBackDisabled"}}><i class="icon-trash"></i>
+                <a class="btn btn-xs" {{action remove target="view"}}{{bindAttr disabled="isBackDisabled"}}><i class="glyphicon glyphicon-trash"></i>
                   {{t common.remove}}</a>
               </td>
               {{/view}}
@@ -124,21 +124,16 @@
           <label>{{t common.show}}: {{view view.rowsPerPageSelectView selectionBinding="view.displayLength"}}</label>
         </div>
         <div class="info">{{view.paginationInfo}}</div>
-        <div class="paging_two_button">
-          {{view view.paginationFirst}}
-          {{view view.paginationLeft}}
-          {{view view.paginationRight}}
-          {{view view.paginationLast}}
-        </div>
+        {{view view.pagination4Btns}}
       </div>
     </div>
   </div>
   {{#if hasMoreRegisteredHosts}}
-    <div {{bindAttr class=":alert alert-warn"}}>
+    <div {{bindAttr class=":alert :alert-warning"}}>
       <a href="#" {{action registeredHostsPopup target="controller"}}>{{view.registeredHostsMessage}}</a>
     </div>
   {{/if}}
-  <div {{bindAttr class=":alert view.status isWarningsBoxVisible::hidden"}}>
+  <div {{bindAttr class=":alert :alert-warning view.status isWarningsBoxVisible::hidden"}}>
     {{view.message}}
     <a href="#" {{action hostWarningsPopup warnings target="controller"}}>{{view.linkText}}</a>
     {{#unless isBootstrapFailed}}
@@ -148,7 +143,7 @@
     {{/unless}}
   </div>
   <div class="btn-area">
-    <button type="button" class="btn pull-left installer-back-btn" {{bindAttr disabled="isBackButtonDisabled"}} {{action back}}>
+    <button type="button" class="btn btn-default pull-left installer-back-btn" {{bindAttr disabled="isBackButtonDisabled"}} {{action back}}>
       &larr; {{t common.back}}
       {{#if App.router.backBtnClickInProgress}}
         {{view App.SpinnerView tagName="span" classNames="service-button-spinner"}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step3/step3_host_warning_popup_footer.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step3/step3_host_warning_popup_footer.hbs b/ambari-web/app/templates/wizard/step3/step3_host_warning_popup_footer.hbs
index d63387b..d906b75 100644
--- a/ambari-web/app/templates/wizard/step3/step3_host_warning_popup_footer.hbs
+++ b/ambari-web/app/templates/wizard/step3/step3_host_warning_popup_footer.hbs
@@ -18,18 +18,18 @@
 
 <div class="update-progress pull-left">
   {{#if view.isUpdateInProgress}}
-    <div class="progress-info active progress">
-      <div class="bar" {{bindAttr style="view.progressWidth"}}></div>
+    <div class="progress">
+      <div class="progress-bar-info active progress-bar" {{bindAttr style="view.progressWidth"}}></div>
     </div>
   {{else}}
-    <label {{bindAttr class="view.updateStatusClass"}}>{{view.updateStatus}}</label>
+    <span {{bindAttr class="view.updateStatusClass"}}>{{view.updateStatus}}</span>
   {{/if}}
 </div>
 {{#if view.parentView.secondary}}
   <button type="button"
           class="btn btn-info" {{bindAttr disabled="view.isUpdateInProgress"}} {{action onSecondary target="view.parentView"}}>
-    <i class="icon-repeat"></i>&nbsp;{{view.parentView.secondary}}</button>
+    <i class="glyphicon glyphicon-repeat"></i>&nbsp;{{view.parentView.secondary}}</button>
 {{/if}}
 {{#if view.parentView.primary}}
-  <button type="button" class="btn" {{action onPrimary target="view.parentView"}}>{{view.parentView.primary}}</button>
+  <button type="button" class="btn btn-default" {{action onPrimary target="view.parentView"}}>{{view.parentView.primary}}</button>
 {{/if}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step3/step3_host_warnings_popup.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step3/step3_host_warnings_popup.hbs b/ambari-web/app/templates/wizard/step3/step3_host_warnings_popup.hbs
index 4553b0e..62ef7a6 100644
--- a/ambari-web/app/templates/wizard/step3/step3_host_warnings_popup.hbs
+++ b/ambari-web/app/templates/wizard/step3/step3_host_warnings_popup.hbs
@@ -21,34 +21,45 @@
   <div class="notice">
     <span>{{t installer.step3.hostWarningsPopup.checks}} <b>{{view.warningsNotice}}</b>.<br>{{t installer.step3.hostWarningsPopup.notice}}</span>
   </div>
-  <div class="row-fluid">
-    <div class="span7">
-      {{t common.hosts}}&nbsp;{{view view.hostSelectView}}
-    </div>
-    {{#if view.totalWarningsCount}}
-      <div class="span3 offset2">
-        <a href="javascript:void(null)" title="Show Details" {{action openWarningsInDialog target="view"}}
-           class="task-detail-open-dialog"><i
-            class="icon-external-link"></i> {{t installer.step3.hostWarningsPopup.report}}</a>
+  <div class="row">
+    <form class="form-horizontal">
+      <div class="from-group">
+        <div class="col-md-2">
+          <label class="control-label">
+            {{t common.hosts}}
+          </label>
+        </div>
+        <div class="col-md-5">
+          {{view view.hostSelectView classNames="form-control input-sm"}}
+        </div>
+        {{#if view.totalWarningsCount}}
+          <div class="col-md-3 col-md-offset-2">
+            <a href="javascript:void(null)" title="Show Details" {{action openWarningsInDialog target="view"}}
+               class="task-detail-open-dialog control-label display-inline-block">
+               <i class="icon-external-link"></i>&nbsp;
+               {{t installer.step3.hostWarningsPopup.report}}
+            </a>
+          </div>
+        {{/if}}
       </div>
-    {{/if}}
+    </form>
   </div>
-  <div class="accordion warnings-list" id="accordion2">
+  <div class="panel warnings-list" id="accordion2">
     {{#each category in view.content}}
-      <div class="accordion-group block">
-        <div class="accordion-heading" {{action onToggleBlock category}}>
-          <i {{bindAttr class=":pull-left :accordion-toggle category.isCollapsed:icon-caret-right:icon-caret-down"}}></i>
-          {{#if category.warnings.length}}
-            <i class="pull-right accordion-toggle icon-warning-sign"></i>
-          {{else}}
-            <i class="pull-right accordion-toggle icon-ok"></i>
-          {{/if}}
-          <a class="accordion-toggle">
-            {{category.title}} ({{category.warnings.length}})
-          </a>
-        </div>
-        <div id="{{unbound category.category}}" class="accordion-body collapse in" style="display: none">
-          <div class="accordion-inner">
+      <div class="panel-group block">
+        <div class="panel panel-default">
+          <div class="panel-heading" {{action onToggleBlock category}}>
+            <i {{bindAttr class=":pull-left :panel-toggle category.isCollapsed:icon-caret-right:icon-caret-down"}}></i>
+            {{#if category.warnings.length}}
+              <i class="pull-right panel-toggle icon-warning-sign"></i>
+            {{else}}
+              <i class="pull-right panel-toggle glyphicon glyphicon-ok"></i>
+            {{/if}}
+            <a class="panel-toggle">
+              {{category.title}} ({{category.warnings.length}})
+            </a>
+          </div>
+          <div id="{{unbound category.category}}" class="panel-body collapse in" style="display: none">
             {{#if category.warnings.length}}
               <table>
                 <thead>

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step4.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step4.hbs b/ambari-web/app/templates/wizard/step4.hbs
index c62d369..97f4104 100644
--- a/ambari-web/app/templates/wizard/step4.hbs
+++ b/ambari-web/app/templates/wizard/step4.hbs
@@ -25,7 +25,7 @@
   <table class="table table-striped">
     <thead>
     <tr>
-      <th class="span3" id="service-name">
+      <th class="col-md-3" id="service-name">
           {{view Ember.Checkbox disabledBinding="isInstalled" checkedBinding="isAllChecked"}}{{t common.service}}
       </th>
       <th id="service-version">{{t common.version}}</th>
@@ -36,9 +36,15 @@
     {{#each controller}}
       {{#unless isHiddenOnSelectServicePage}}
         <tr {{bindAttr class="isSelected:success isSelected:service-selected"}}>
-          <td><label class="checkbox">{{view Ember.Checkbox classBinding="serviceName"
-          disabledBinding="isInstalled"
-          checkedBinding="isSelected"}}{{displayNameOnSelectServicePage}}</label>
+          <td>
+            <div class="checkbox">
+              <label>
+                {{view Ember.Checkbox classBinding="serviceName"
+                  disabledBinding="isInstalled"
+                  checkedBinding="isSelected"}}
+                  {{displayNameOnSelectServicePage}}
+              </label>
+            </div>
           </td>
           <td>{{serviceVersionDisplay}}</td>
           <td>{{{comments}}}</td>
@@ -50,7 +56,7 @@
 
   <div class="btn-area">
     {{#unless view.parentView.controller.hideBackButton}}
-      <button type="button" class="btn pull-left installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
+      <button type="button" class="btn btn-default pull-left installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
         &larr; {{t common.back}}
         {{#if App.router.backBtnClickInProgress}}
           {{view App.SpinnerView tagName="span" classNames="service-button-spinner"}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step4/step4_ranger_requirements_popup.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step4/step4_ranger_requirements_popup.hbs b/ambari-web/app/templates/wizard/step4/step4_ranger_requirements_popup.hbs
index 5057462..121245c 100644
--- a/ambari-web/app/templates/wizard/step4/step4_ranger_requirements_popup.hbs
+++ b/ambari-web/app/templates/wizard/step4/step4_ranger_requirements_popup.hbs
@@ -17,4 +17,9 @@
 }}
 
 {{t installer.step4.rangerRequirements.popup.body.requirements}}
-<label class="checkbox">{{view Em.Checkbox checkedBinding="isChecked"}}{{t installer.step4.rangerRequirements.popup.body.confirmation}}</label>
+<div class="checkbox">
+  <label>
+    {{view Em.Checkbox checkedBinding="isChecked"}}
+    {{t installer.step4.rangerRequirements.popup.body.confirmation}}
+  </label>
+</div>

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step6.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step6.hbs b/ambari-web/app/templates/wizard/step6.hbs
index 126c9a6..cb1e575 100644
--- a/ambari-web/app/templates/wizard/step6.hbs
+++ b/ambari-web/app/templates/wizard/step6.hbs
@@ -21,7 +21,7 @@
 
   <div class="alert alert-info">{{{view.label}}}</div>
   {{#if anyGeneralIssues}}
-    <div class="alert alert-error">
+    <div class="alert alert-danger">
       {{t installer.step6.validationSlavesAndClients.hasIssues}}
       <a href="javascript:void(null);" {{action openSlavesAndClientsIssues target="controller"}}>{{t installer.step6.validationSlavesAndClients.click}}</a>
       {{t installer.step6.validationSlavesAndClients.forDetails}}
@@ -49,17 +49,21 @@
         {{#each host in view.pageContent}}
           <tr>
             {{#view App.WizardStep6HostView hostBinding="host" }}
-              <span class="trim_hostname">{{host.hostName}}</span>
-              {{#if host.hasMaster}}
-                <i class=icon-asterisks>&#10037;</i>
-              {{/if}}
+              <div class="checkbox">
+                <span class="trim_hostname">{{host.hostName}}</span>
+                {{#if host.hasMaster}}
+                  <i class="glyphicon glyphicon-asterisks">&#10037;</i>
+                {{/if}}
+              </div>
             {{/view}}
             {{#each checkbox in host.checkboxes}}
               <td {{bindAttr class="checkbox.hasErrorMessage:error checkbox.hasWarnMessage:warning checkbox.component"}}>
-                <label class="checkbox">
-                  <input {{bindAttr checked = "checkbox.checked" disabled="checkbox.isDisabled"}} {{action "checkboxClick" checkbox target="view" }}
-                          type="checkbox"/>{{checkbox.title}}
-                </label>
+                <div class="checkbox">
+                  <label>
+                    <input {{bindAttr checked = "checkbox.checked" disabled="checkbox.isDisabled"}} {{action "checkboxClick" checkbox target="view" }}
+                            type="checkbox"/>{{checkbox.title}}
+                  </label>
+                </div>
               </td>
             {{/each}}
           </tr>
@@ -67,7 +71,7 @@
             <tr>
               <td {{bindAttr colspan="view.columnCount"}} class="no-borders">
                 {{#each errorMsg in host.errorMessages}}
-                    <div class="alert alert-error">{{errorMsg}}</div>
+                    <div class="alert alert-danger">{{errorMsg}}</div>
                 {{/each}}
                 {{#each warnMsg in host.warnMessages}}
                   <div class="alert alert-warning">{{warnMsg}}</div>
@@ -85,16 +89,11 @@
         <label>{{t common.show}}: {{view view.rowsPerPageSelectView selectionBinding="view.displayLength"}}</label>
       </div>
       <div class="info">{{view.paginationInfo}}</div>
-      <div class="paging_two_button">
-        {{view view.paginationFirst}}
-        {{view view.paginationLeft}}
-        {{view view.paginationRight}}
-        {{view view.paginationLast}}
-      </div>
+      {{view view.pagination4Btns}}
     </div>
   </div>
   <div class="btn-area">
-    <button type="button" class="btn installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
+    <button type="button" class="btn btn-default installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
       &larr; {{t common.back}}
       {{#if App.router.backBtnClickInProgress}}
         {{view App.SpinnerView tagName="span" classNames="service-button-spinner"}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step6/step6_issues_popup.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step6/step6_issues_popup.hbs b/ambari-web/app/templates/wizard/step6/step6_issues_popup.hbs
index 447ff50..c2201d3 100644
--- a/ambari-web/app/templates/wizard/step6/step6_issues_popup.hbs
+++ b/ambari-web/app/templates/wizard/step6/step6_issues_popup.hbs
@@ -19,7 +19,7 @@
 <p>{{t installer.step6.validationSlavesAndClients.popup.body}}</p>
 <div class="limited-height-2">
   {{#if anyGeneralErrors}}
-    <div class="alert alert-error">
+    <div class="alert alert-danger">
       <ul>
         {{#if errorMessage}}
           <li>{{errorMessage}}</li>

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step7.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step7.hbs b/ambari-web/app/templates/wizard/step7.hbs
index f6d640b..0f8fa8d 100644
--- a/ambari-web/app/templates/wizard/step7.hbs
+++ b/ambari-web/app/templates/wizard/step7.hbs
@@ -31,7 +31,7 @@
 
 
   <div class="btn-area">
-    <button type="button" class="btn installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
+    <button type="button" class="btn btn-default installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
       &larr; {{t common.back}}
       {{#if App.router.backBtnClickInProgress}}
         {{view App.SpinnerView tagName="span" classNames="service-button-spinner"}}
@@ -39,7 +39,7 @@
     </button>
     <div class="pull-right">
       {{#if App.supports.preInstallChecks}}
-        <a class="btn" {{action runPreInstallChecks target="App.router.preInstallChecksController"}} {{bindAttr disabled="isSubmitDisabled"}}><i class="icon-exclamation"></i> {{t installer.step7.preInstallChecks}}</a>
+        <a class="btn btn-default" {{action runPreInstallChecks target="App.router.preInstallChecksController"}} {{bindAttr disabled="isSubmitDisabled"}}><i class="glyphicon glyphicon-exclamation"></i> {{t installer.step7.preInstallChecks}}</a>
       {{/if}}
       <button type="button" class="btn btn-success" {{bindAttr disabled="isSubmitDisabled"}} {{action submit target="controller"}}>
         {{#if App.router.nextBtnClickInProgress}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step8.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step8.hbs b/ambari-web/app/templates/wizard/step8.hbs
index caa2e28..1af0683 100644
--- a/ambari-web/app/templates/wizard/step8.hbs
+++ b/ambari-web/app/templates/wizard/step8.hbs
@@ -78,7 +78,7 @@
     </div>
   </div>
   <div class="btn-area">
-    <button type="button" class="btn pull-left installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
+    <button type="button" class="btn btn-default pull-left installer-back-btn" {{bindAttr disabled="App.router.btnClickInProgress"}} {{action back}}>
       &larr; {{t common.back}}
       {{#if App.router.backBtnClickInProgress}}
         {{view App.SpinnerView tagName="span" classNames="service-button-spinner"}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step8/step8_log_popup.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step8/step8_log_popup.hbs b/ambari-web/app/templates/wizard/step8/step8_log_popup.hbs
index 6d3e5c2..e16c785 100644
--- a/ambari-web/app/templates/wizard/step8/step8_log_popup.hbs
+++ b/ambari-web/app/templates/wizard/step8/step8_log_popup.hbs
@@ -17,6 +17,6 @@
 }}
 <p>{{view.message}}</p>
 <div {{bindAttr class="view.progressBarClass"}}>
-    <div class="bar" {{bindAttr style="view.barWidth"}}>
+    <div class="progress-bar progress-bar-striped active" {{bindAttr style="view.barWidth"}}>
     </div>
 </div>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step9.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step9.hbs b/ambari-web/app/templates/wizard/step9.hbs
index c45c3b1..cdfb797 100644
--- a/ambari-web/app/templates/wizard/step9.hbs
+++ b/ambari-web/app/templates/wizard/step9.hbs
@@ -23,14 +23,14 @@
   <p class="alert alert-info">{{t installer.step9.body}}</p>
 
   <div id="overallProgress">
-    <div class="row-fluid">
-      <div class="span10">
-        <div {{bindAttr class="view.isStepCompleted::progress-striped view.isStepCompleted::active view.barColor :progress"}}>
-          <div class="bar" {{bindAttr style="view.barWidth"}}>
+    <div class="row">
+      <div class="col-md-10">
+        <div class="progress">
+          <div {{bindAttr class="view.isStepCompleted::progress-bar-striped view.isStepCompleted::active view.barColor :progress-bar"}} {{bindAttr style="view.barWidth"}}>
           </div>
         </div>
       </div>
-      <div class="span2">{{view.progressMessage}}</div>
+      <div class="col-md-2">{{view.progressMessage}}</div>
     </div>
   </div>
 
@@ -39,7 +39,7 @@
       <div class="pull-left">
         {{#if controller.showRetry}}
           <a class="btn btn-primary" href="#" {{action retry}}>
-            <i class="icon-repeat icon-white"></i>
+            <i class="glyphicon glyphicon-repeat glyphicon-white"></i>
             {{t common.retry}}
           </a>
         {{/if}}
@@ -83,15 +83,15 @@
                 <span title="{{unbound host.name}}" class="trim_hostname">{{host.name}}</span>
               </td>
               <td>
-                <div class="progress-bar pull-left">
-                  <div {{bindAttr class="view.isHostCompleted::progress-striped view.isHostCompleted::active view.barColor :progress"}}>
-                    <div class="bar" {{bindAttr style="view.barWidth"}}></div>
+                <div class="progress-wrapper pull-left">
+                  <div class="progress">
+                    <div {{bindAttr class="view.isHostCompleted::active view.isHostCompleted::progress-bar-striped view.barColor :progress-bar" style="view.barWidth"}}></div>
                   </div>
                 </div>
                 <div class="progress-percentage pull-left">{{host.progress}}%</div>
               </td>
               <td class="host-message">
-                <a {{bindAttr class="view.isFailed:text-error view.isSuccess:text-success view.isWarning:text-warning"}}
+                <a {{bindAttr class="view.isFailed:text-danger view.isSuccess:text-success view.isWarning:text-warning"}}
                     href="javascript:void(null)"
                     data-toggle="modal" {{action hostLogPopup target="view"}}>{{host.message}}</a>
               </td>
@@ -116,19 +116,14 @@
           <label>{{t common.show}}: {{view view.rowsPerPageSelectView selectionBinding="view.displayLength"}}</label>
         </div>
         <div class="info">{{view.paginationInfo}}</div>
-        <div class="paging_two_button">
-          {{view view.paginationFirst}}
-          {{view view.paginationLeft}}
-          {{view view.paginationRight}}
-          {{view view.paginationLast}}
-        </div>
+        {{view view.pagination4Btns}}
       </div>
     </div>
   </div>
 
   <div>
     {{#if view.resultMsg}}
-      <p {{bindAttr class="view.resultMsgColor :alert"}}>{{view.resultMsg}}
+      <p {{bindAttr class="view.resultMsgColor :alert :alert-warning"}}>{{view.resultMsg}}
         {{#if view.isHostHeartbeatLost}}
           <a href="javascript:void(null)"
              data-toggle="modal" {{action hostWithInstallFailed target="view"}}>{{t common.showDetails}}</a>

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step9/step9HostTasksLogPopup.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step9/step9HostTasksLogPopup.hbs b/ambari-web/app/templates/wizard/step9/step9HostTasksLogPopup.hbs
index 0da14bd..6434d97 100644
--- a/ambari-web/app/templates/wizard/step9/step9HostTasksLogPopup.hbs
+++ b/ambari-web/app/templates/wizard/step9/step9HostTasksLogPopup.hbs
@@ -47,7 +47,7 @@
                   {{taskInfo.commandDetail}}
                 </a>
               </div>
-              <div class="show-details"><i class="icon-caret-right"></i></div>
+              <div class="show-details"><i class="glyphicon glyphicon-caret-right"></i></div>
             </div>
           </div>
         {{/each}}
@@ -60,13 +60,13 @@
     <div {{bindAttr class="view.isLogWrapHidden:hidden :task-detail-info"}}>
       <div class="task-top-wrap">
         <a class="task-detail-back" href="javascript:void(null)" {{action backToTaskList}} ><i
-                class="icon-arrow-left"></i>&nbsp;{{t common.tasks}}</a>
+                class="glyphicon glyphicon-arrow-left"></i>&nbsp;{{t common.tasks}}</a>
 
         <div>
           <i {{bindAttr class="view.openedTask.status :task-detail-status-ico view.openedTask.icon"}}></i>
           <div class="task-detail-ico-wrap">
-            <a title="Click to Copy" {{action "textTrigger" taskInfo target="view"}} class="task-detail-copy"><i class="icon-copy"></i> {{t common.copy}}</a>
-            <a {{translateAttr title="common.openNewWindow"}} {{action openTaskLogInDialog}} class="task-detail-open-dialog"><i class="icon-external-link"></i> {{t common.open}}</a>
+            <a title="Click to Copy" {{action "textTrigger" taskInfo target="view"}} class="task-detail-copy"><i class="glyphicon glyphicon-copy"></i> {{t common.copy}}</a>
+            <a {{translateAttr title="common.openNewWindow"}} {{action openTaskLogInDialog}} class="task-detail-open-dialog"><i class="glyphicon glyphicon-external-link"></i> {{t common.open}}</a>
           </div>
           <span class="task-detail-log-rolename">
             {{view.openedTask.commandDetail}}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/templates/wizard/step9/step9_install_host_popup.hbs
----------------------------------------------------------------------
diff --git a/ambari-web/app/templates/wizard/step9/step9_install_host_popup.hbs b/ambari-web/app/templates/wizard/step9/step9_install_host_popup.hbs
index 5da8642..9dd6344 100644
--- a/ambari-web/app/templates/wizard/step9/step9_install_host_popup.hbs
+++ b/ambari-web/app/templates/wizard/step9/step9_install_host_popup.hbs
@@ -20,8 +20,8 @@
   <table class="table table-striped">
     <thead>
     <tr>
-      <th class="span3">{{t common.host}}</th>
-      <th class="span3">{{t common.components}}</th>
+      <th class="col-md-3">{{t common.host}}</th>
+      <th class="col-md-3">{{t common.components}}</th>
     </tr>
     </thead>
     <tbody>

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/utils/bootstrap_reopen.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/utils/bootstrap_reopen.js b/ambari-web/app/utils/bootstrap_reopen.js
new file mode 100644
index 0000000..191cd95
--- /dev/null
+++ b/ambari-web/app/utils/bootstrap_reopen.js
@@ -0,0 +1,42 @@
+/**
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+/**
+ * This file contains patched methods for twitter bootstrap.js
+ */
+
+/**
+ * Fixes error when <code>destroy</code> method called more than one time.
+ * For more info check https://github.com/twbs/bootstrap/issues/20511
+ */
+$.fn.tooltip.Constructor.prototype.destroy = function() {
+  var that = this
+  clearTimeout(this.timeout)
+  this.hide(function () {
+    if (that.$element !== null) {
+      that.$element.off('.' + that.type).removeData('bs.' + that.type)
+    }
+    if (that.$tip) {
+      that.$tip.detach()
+    }
+    that.$tip = null
+    that.$arrow = null
+    that.$viewport = null
+    that.$element = null
+  })
+}

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/utils/ember_reopen.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/utils/ember_reopen.js b/ambari-web/app/utils/ember_reopen.js
index bf091da..a616e49 100644
--- a/ambari-web/app/utils/ember_reopen.js
+++ b/ambari-web/app/utils/ember_reopen.js
@@ -144,12 +144,11 @@ Ember.RadioButton = Ember.Checkbox.extend({
   tagName: "input",
   type: "radio",
   attributeBindings: [ "type", "name", "value", "checked", "style", "disabled" ],
-  style: "vertical-align: middle; margin: 0px;",
   click: function () {
     this.set("selection", this.$().val())
   },
   checked: function () {
-    return this.get("value") == this.get("selection");
+    return this.get("value") === this.get("selection");
   }.property('value', 'selection')
 });
 

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/utils/handlebars_helpers.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/utils/handlebars_helpers.js b/ambari-web/app/utils/handlebars_helpers.js
index eca816c..68e2283 100644
--- a/ambari-web/app/utils/handlebars_helpers.js
+++ b/ambari-web/app/utils/handlebars_helpers.js
@@ -91,7 +91,7 @@ App.registerBoundHelper('formatWordBreak', App.FormatWordBreakView);
  * Examples:
  *
  * {{statusIcon view.status}}
- * returns 'icon-cog'
+ * returns 'glyphicon glyphicon-cog'
  *
  */
 App.registerBoundHelper('statusIcon', App.StatusIconView);

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/utils/helper.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/utils/helper.js b/ambari-web/app/utils/helper.js
index 11da9d0..52dcd23 100644
--- a/ambari-web/app/utils/helper.js
+++ b/ambari-web/app/utils/helper.js
@@ -758,10 +758,13 @@ App.format = {
  * @param {object} options
  */
 App.popover = function (self, options) {
+  var opts = $.extend(true, {
+    container: 'body'
+  }, options || {});
   if (!self) return;
-  self.popover(options);
+  self.popover(opts);
   self.on("remove", function () {
-    $(this).trigger('mouseleave').off().removeData('popover');
+    $(this).trigger('mouseleave').off().removeData('bs.popover');
   });
 };
 
@@ -774,11 +777,14 @@ App.popover = function (self, options) {
  * @param {object} options
  */
 App.tooltip = function (self, options) {
+  var opts = $.extend(true, {
+    container: 'body'
+  }, options || {});
   if (!self || !self.tooltip) return;
-  self.tooltip(options);
+  self.tooltip(opts);
   /* istanbul ignore next */
   self.on("remove", function () {
-    $(this).trigger('mouseleave').off().removeData('tooltip');
+    $(this).trigger('mouseleave').off().removeData('bs.tooltip');
   });
 };
 

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/utils/host_progress_popup.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/utils/host_progress_popup.js b/ambari-web/app/utils/host_progress_popup.js
index a29aee5..97ecbb8 100644
--- a/ambari-web/app/utils/host_progress_popup.js
+++ b/ambari-web/app/utils/host_progress_popup.js
@@ -156,11 +156,11 @@ App.HostPopup = Em.Object.create({
    * @type {object}
    */
   barColorMap: {
-    'FAILED': 'progress-danger',
-    'ABORTED': 'progress-warning',
-    'TIMEDOUT': 'progress-warning',
-    'IN_PROGRESS': 'progress-info',
-    'COMPLETED': 'progress-success'
+    'FAILED': 'progress-bar-danger',
+    'ABORTED': 'progress-bar-warning',
+    'TIMEDOUT': 'progress-bar-warning',
+    'IN_PROGRESS': 'progress-bar-info',
+    'COMPLETED': 'progress-bar-success'
   },
 
   /**
@@ -169,11 +169,11 @@ App.HostPopup = Em.Object.create({
    * @type {object}
    */
   statusesStyleMap: {
-    'FAILED': ['FAILED', 'icon-exclamation-sign', 'progress-danger', false],
-    'ABORTED': ['ABORTED', 'icon-minus', 'progress-warning', false],
-    'TIMEDOUT': ['TIMEDOUT', 'icon-time', 'progress-warning', false],
-    'IN_PROGRESS': ['IN_PROGRESS', 'icon-cogs', 'progress-info', true],
-    'COMPLETED': ['SUCCESS', 'icon-ok', 'progress-success', false]
+    'FAILED': ['FAILED', 'icon-exclamation-sign', 'progress-bar-danger', false],
+    'ABORTED': ['ABORTED', 'glyphicon glyphicon-minus', 'progress-bar-warning', false],
+    'TIMEDOUT': ['TIMEDOUT', 'glyphicon glyphicon-time', 'progress-bar-warning', false],
+    'IN_PROGRESS': ['IN_PROGRESS', 'glyphicon glyphicon-cogs', 'progress-bar-info', true],
+    'COMPLETED': ['SUCCESS', 'glyphicon glyphicon-ok', 'progress-bar-success', false]
   },
 
   /**
@@ -351,22 +351,22 @@ App.HostPopup = Em.Object.create({
         isCompleted = false;
       }
       if (taskStatus === 'FAILED') {
-        return ['FAILED', 'icon-exclamation-sign', 'progress-danger', false];
+        return ['FAILED', 'icon-exclamation-sign', 'progress-bar-danger', false];
       }
       if (taskStatus === 'ABORTED') {
-        return ['ABORTED', 'icon-minus', 'progress-warning', false];
+        return ['ABORTED', 'glyphicon glyphicon-minus', 'progress-bar-warning', false];
       }
       if (taskStatus === 'TIMEDOUT') {
-        return ['TIMEDOUT', 'icon-time', 'progress-warning', false];
+        return ['TIMEDOUT', 'glyphicon glyphicon-time', 'progress-bar-warning', false];
       }
       if (taskStatus === 'IN_PROGRESS') {
-        return ['IN_PROGRESS', 'icon-cogs', 'progress-info', true]
+        return ['IN_PROGRESS', 'glyphicon glyphicon-cogs', 'progress-bar-info', true]
       }
     }
     if (isCompleted) {
-      return ['SUCCESS', 'icon-ok', 'progress-success', false];
+      return ['SUCCESS', 'glyphicon glyphicon-ok', 'progress-bar-success', false];
     }
-    return ['PENDING', 'icon-cog', 'progress-info', true];
+    return ['PENDING', 'glyphicon glyphicon-cog', 'progress-bar-info', true];
   },
 
   /**
@@ -469,7 +469,7 @@ App.HostPopup = Em.Object.create({
    */
   createService: function (service) {
     var statuses = this.get('statusesStyleMap');
-    var pendingStatus = ['PENDING', 'icon-cog', 'progress-info', true];
+    var pendingStatus = ['PENDING', 'glyphicon glyphicon-cog', 'progress-bar-info', true];
     var status = statuses[service.status] || pendingStatus;
     return Em.Object.create({
       id: service.id,
@@ -500,7 +500,7 @@ App.HostPopup = Em.Object.create({
    */
   updateService: function (service, newData) {
     var statuses = this.get('statusesStyleMap');
-    var pendingStatus = ['PENDING', 'icon-cog', 'progress-info', true];
+    var pendingStatus = ['PENDING', 'glyphicon glyphicon-cog', 'progress-bar-info', true];
     var status = statuses[newData.status] || pendingStatus;
     return service.setProperties({
       progress: newData.progress,
@@ -558,15 +558,15 @@ App.HostPopup = Em.Object.create({
       duration: date.durationSummary(_task.Tasks.start_time, _task.Tasks.end_time),
       icon: function () {
         var statusIconMap = {
-          'pending': 'icon-cog',
-          'queued': 'icon-cog',
-          'in_progress': 'icon-cogs',
-          'completed': 'icon-ok',
+          'pending': 'glyphicon glyphicon-cog',
+          'queued': 'glyphicon glyphicon-cog',
+          'in_progress': 'glyphicon glyphicon-cogs',
+          'completed': 'glyphicon glyphicon-ok',
           'failed': 'icon-exclamation-sign',
-          'aborted': 'icon-minus',
-          'timedout': 'icon-time'
+          'aborted': 'glyphicon glyphicon-minus',
+          'timedout': 'glyphicon glyphicon-time'
         };
-        return statusIconMap[this.get('status')] || 'icon-cog';
+        return statusIconMap[this.get('status')] || 'glyphicon glyphicon-cog';
       }.property('status')
     });
   },
@@ -659,8 +659,8 @@ App.HostPopup = Em.Object.create({
         status: App.format.taskStatus("PENDING"),
         serviceName: _host.serviceName,
         isVisible: true,
-        icon: "icon-cog",
-        barColor: "progress-info",
+        icon: "glyphicon glyphicon-cog",
+        barColor: "progress-bar-info",
         barWidth: "width:0%;"
       });
 
@@ -856,7 +856,8 @@ App.HostPopup = Em.Object.create({
       /**
        * @type {String[]}
        */
-      classNames: ['sixty-percent-width-modal', 'host-progress-popup', 'full-height-modal'],
+      classNames: ['common-modal-wrapper', 'host-progress-popup', 'full-height-modal'],
+      modalDialogClasses: ['modal-lg'],
 
       /**
        * Auto-display BG-popup

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/utils/hosts.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/utils/hosts.js b/ambari-web/app/utils/hosts.js
index 0aebe89..3896325 100644
--- a/ambari-web/app/utils/hosts.js
+++ b/ambari-web/app/utils/hosts.js
@@ -51,7 +51,8 @@ module.exports = {
     }
     App.ModalPopup.show({
 
-      classNames: [ 'sixty-percent-width-modal' ],
+      classNames: [ 'common-modal-wrapper' ],
+      modalDialogClasses: ['modal-lg'],
 
       elementId: 'host-selection-dialog',
 

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/utils/load_timer.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/utils/load_timer.js b/ambari-web/app/utils/load_timer.js
index 8cfa5cb..eebb81b 100644
--- a/ambari-web/app/utils/load_timer.js
+++ b/ambari-web/app/utils/load_timer.js
@@ -55,8 +55,8 @@ App.loadTimer = Em.Object.create({
    * @param {string} result
    */
   display: function(result) {
-    var alert = $("<div class='alert attach-to-bottom-right'>" +  result + "</div>");
-    var closeButton = $("<i class='icon-remove-circle'></i>").click(function () {
+    var alert = $("<div class='alert alert-warning attach-to-bottom-right'>" +  result + "</div>");
+    var closeButton = $("<i class='glyphicon glyphicon-remove-circle'></i>").click(function () {
       $(this).remove();
       $(alert).remove();
     });

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/assign_master_components_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/assign_master_components_view.js b/ambari-web/app/views/common/assign_master_components_view.js
index 37054c3..d838eef 100644
--- a/ambari-web/app/views/common/assign_master_components_view.js
+++ b/ambari-web/app/views/common/assign_master_components_view.js
@@ -127,6 +127,7 @@ App.InputHostView = Em.TextField.extend(App.SelectHost, {
 
 App.SelectHostView = Em.Select.extend(App.SelectHost, {
 
+  classNames: ['form-control'],
   attributeBindings: ['disabled'],
 
   didInsertElement: function () {
@@ -172,7 +173,7 @@ App.AddControlView = Em.View.extend({
 
   tagName: "span",
 
-  classNames: ["badge", "badge-important"],
+  classNames: ["badge"],
 
   classNameBindings: ['uniqueId'],
 
@@ -211,7 +212,7 @@ App.RemoveControlView = Em.View.extend({
 
   tagName: "span",
 
-  classNames: ["badge", "badge-important"],
+  classNames: ["badge"],
 
   template: Em.Handlebars.compile('-'),
 

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/chart/linear_time.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/chart/linear_time.js b/ambari-web/app/views/common/chart/linear_time.js
index 8eaf6f3..919d7fa 100644
--- a/ambari-web/app/views/common/chart/linear_time.js
+++ b/ambari-web/app/views/common/chart/linear_time.js
@@ -309,7 +309,7 @@ App.ChartLinearTimeView = Ember.View.extend(App.ExportMetricsMixin, {
           icon.on('mouseover', function () {
             $(this).closest("[rel='ZoomInTooltip']").trigger('mouseleave');
           });
-          App.tooltip(icon.children('.icon-save'), {
+          App.tooltip(icon.children('.glyphicon-save'), {
             title: Em.I18n.t('common.export')
           });
         }
@@ -430,7 +430,7 @@ App.ChartLinearTimeView = Ember.View.extend(App.ExportMetricsMixin, {
     var typeClass;
     switch (type) {
       case 'error':
-        typeClass = 'alert-error';
+        typeClass = 'alert-danger';
         break;
       case 'success':
         typeClass = 'alert-success';
@@ -439,7 +439,7 @@ App.ChartLinearTimeView = Ember.View.extend(App.ExportMetricsMixin, {
         typeClass = 'alert-info';
         break;
       default:
-        typeClass = '';
+        typeClass = 'alert-warning';
         break;
     }
     $(chartOverlayId + ', ' + chartOverlayY + ', ' + chartOverlayX + ', ' + chartOverlayLegend + ', ' + chartOverlayTimeline).html('');
@@ -970,11 +970,11 @@ App.ChartLinearTimeView = Ember.View.extend(App.ExportMetricsMixin, {
         didInsertElement: function () {
           var popupBody = this;
           this._super();
-          App.tooltip(this.$('.corner-icon > .icon-save'), {
+          App.tooltip(this.$('.corner-icon > .glyphicon-save'), {
             title: Em.I18n.t('common.export')
           });
           this.$().closest('.modal').on('click', function (event) {
-            if (!($(event.target).is('.corner-icon, .corner-icon span, .icon-save, .export-graph-list-container, .export-graph-list-container *'))) {
+            if (!($(event.target).is('.corner-icon, .corner-icon span, .glyphicon-save, .export-graph-list-container, .export-graph-list-container *'))) {
               popupBody.set('isExportMenuHidden', true);
             }
           });

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/config_history_flow.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/config_history_flow.js b/ambari-web/app/views/common/configs/config_history_flow.js
index 5ad65ac..0674231 100644
--- a/ambari-web/app/views/common/configs/config_history_flow.js
+++ b/ambari-web/app/views/common/configs/config_history_flow.js
@@ -377,6 +377,7 @@ App.ConfigHistoryFlowView = Em.View.extend({
       serviceConfigNote: Em.I18n.t('services.service.config.configHistory.makeCurrent.message').format(versionText),
       bodyClass: Em.View.extend({
         templateName: require('templates/common/configs/save_configuration'),
+        classNames: ['col-md-12'],
         notesArea: Em.TextArea.extend({
           classNames: ['full-width'],
           value: Em.I18n.t('services.service.config.configHistory.makeCurrent.message').format(versionText),
@@ -446,6 +447,7 @@ App.ConfigHistoryFlowView = Em.View.extend({
       serviceConfigNote: '',
       bodyClass: Em.View.extend({
         templateName: require('templates/common/configs/save_configuration'),
+        classNames: ['col-md-12'],
         showPasswordChangeWarning: passwordWasChanged,
         notesArea: Em.TextArea.extend({
           classNames: ['full-width'],
@@ -539,9 +541,7 @@ App.ConfigsServiceVersionBoxView = Em.View.extend({
   didInsertElement: function () {
     this._super();
     this.$('.version-box').hoverIntent(function() {
-      if ($(this).is(':hover')) {
-        $(this).find('.version-popover').delay(700).fadeIn(200).end();
-      }
+      $(this).find('.version-popover').delay(700).fadeIn(200).end();
     }, function() {
       $(this).find('.version-popover').stop().fadeOut(200).end();
     });

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/controls_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/controls_view.js b/ambari-web/app/views/common/configs/controls_view.js
index de7002c..8894ea6 100644
--- a/ambari-web/app/views/common/configs/controls_view.js
+++ b/ambari-web/app/views/common/configs/controls_view.js
@@ -19,7 +19,7 @@ var App = require('app');
 
 App.ControlsView = Ember.View.extend({
 
-	classNames: ['display-inline-block'],
+	classNames: ['display-inline-block', 'config-controls'],
 
 	templateName: require('templates/common/configs/controls'),
 

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/service_config_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/service_config_view.js b/ambari-web/app/views/common/configs/service_config_view.js
index d48ab16..daf26b0 100644
--- a/ambari-web/app/views/common/configs/service_config_view.js
+++ b/ambari-web/app/views/common/configs/service_config_view.js
@@ -128,7 +128,7 @@ App.ServiceConfigView = Em.View.extend({
       this.$('.service-body').hide();
     }
     App.tooltip($(".restart-required-property"), {html: true});
-    App.tooltip($(".icon-lock"), {placement: 'right'});
+    App.tooltip($(".glyphicon .glyphicon-lock"), {placement: 'right'});
     App.tooltip($("[rel=tooltip]"));
     this.checkCanEdit();
   },

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/service_configs_by_category_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/widgets/checkbox_config_widget_view.js b/ambari-web/app/views/common/configs/widgets/checkbox_config_widget_view.js
index 8ab8088..a477227 100644
--- a/ambari-web/app/views/common/configs/widgets/checkbox_config_widget_view.js
+++ b/ambari-web/app/views/common/configs/widgets/checkbox_config_widget_view.js
@@ -35,9 +35,9 @@ App.CheckboxConfigWidgetView = App.ConfigWidgetView.extend({
       if (self.$())
       self.$('input[type="checkbox"]:eq(0)').checkbox({
         defaultState: self.get('config.value'),
-        buttonStyle: 'btn-link btn-large',
-        checkedClass: 'icon-check',
-        uncheckedClass: 'icon-check-empty'
+        buttonStyle: 'btn-link',
+        checkedClass: 'glyphicon glyphicon-check',
+        uncheckedClass: 'glyphicon glyphicon-unchecked'
       });
     });
   },

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/widgets/config_widget_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/widgets/config_widget_view.js b/ambari-web/app/views/common/configs/widgets/config_widget_view.js
index da4ed6c..62b6057 100644
--- a/ambari-web/app/views/common/configs/widgets/config_widget_view.js
+++ b/ambari-web/app/views/common/configs/widgets/config_widget_view.js
@@ -142,7 +142,7 @@ App.ConfigWidgetView = Em.View.extend(App.SupportsDependentConfigs, App.WidgetPo
 
     tagName: 'i',
 
-    classNames: ['icon-warning-sign'],
+    classNames: ['glyphicon glyphicon-warning-sign'],
 
     classNameBindings: ['issueIconClass'],
 
@@ -191,7 +191,7 @@ App.ConfigWidgetView = Em.View.extend(App.SupportsDependentConfigs, App.WidgetPo
         ERROR: {
           iconClass: '',
           message: this.get('issuedConfig.errorMessage'),
-          configLabelClass: 'text-error'
+          configLabelClass: 'text-danger'
         },
         WARN: {
           iconClass: 'warning',

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/widgets/directory_config_widget_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/widgets/directory_config_widget_view.js b/ambari-web/app/views/common/configs/widgets/directory_config_widget_view.js
index c698e03..9c3ae6c 100644
--- a/ambari-web/app/views/common/configs/widgets/directory_config_widget_view.js
+++ b/ambari-web/app/views/common/configs/widgets/directory_config_widget_view.js
@@ -34,7 +34,7 @@ App.DirectoryConfigWidgetView = App.ConfigWidgetView.extend({
    */
   configView: App.ServiceConfigTextArea.extend({
     isPopoverEnabled: 'false',
-    widthClass: 'span12',
+    widthClass: 'col-md-12',
     serviceConfigBinding: 'parentView.config',
     popoverPlacement: 'top'
   }),

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/widgets/label_config_widget_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/widgets/label_config_widget_view.js b/ambari-web/app/views/common/configs/widgets/label_config_widget_view.js
index d9f3d5e..9c99469 100644
--- a/ambari-web/app/views/common/configs/widgets/label_config_widget_view.js
+++ b/ambari-web/app/views/common/configs/widgets/label_config_widget_view.js
@@ -1,4 +1,3 @@
-
 /**
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -32,7 +31,7 @@ App.LabelView = App.ConfigWidgetView.extend({
    */
   configView: App.ServiceConfigLabelView.extend({
     isPopoverEnabled: 'false',
-    textFieldClassName: 'span12',
+    textFieldClassName: 'col-md-12',
     serviceConfigBinding: 'parentView.config'
   })
 });

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/widgets/string_config_widget_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/widgets/string_config_widget_view.js b/ambari-web/app/views/common/configs/widgets/string_config_widget_view.js
index 69c0c18..58b5164 100644
--- a/ambari-web/app/views/common/configs/widgets/string_config_widget_view.js
+++ b/ambari-web/app/views/common/configs/widgets/string_config_widget_view.js
@@ -31,7 +31,7 @@ App.StringConfigWidgetView = App.ConfigWidgetView.extend({
    * @property configView
    */
   configView: App.ServiceConfigTextArea.extend({
-    widthClass: 'span12',
+    widthClass: 'col-md-12',
     serviceConfigBinding: 'parentView.config',
     popoverPlacement: 'top'
   }),

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/widgets/textfield_config_widget_view.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/views/common/configs/widgets/textfield_config_widget_view.js b/ambari-web/app/views/common/configs/widgets/textfield_config_widget_view.js
index 1bb97fa..c34c389 100644
--- a/ambari-web/app/views/common/configs/widgets/textfield_config_widget_view.js
+++ b/ambari-web/app/views/common/configs/widgets/textfield_config_widget_view.js
@@ -1,4 +1,3 @@
-
 /**
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -35,7 +34,7 @@ App.TextFieldConfigWidgetView = App.ConfigWidgetView.extend({
     var fieldView = (this.get('config.unit')) ? App.ServiceConfigTextFieldWithUnit : App.ServiceConfigTextField;
     return fieldView.extend({
       isPopoverEnabled: 'false',
-      textFieldClassName: 'span12',
+      textFieldClassName: 'col-md-12',
       serviceConfigBinding: 'parentView.config'
     });
   }.property('config.unit'),
diff --git a/ambari-web/app/views/common/configs/service_configs_by_category_view.js b/ambari-web/app/views/common/configs/service_configs_by_category_view.js
index d9a4c5c..ed6e17a 100644
--- a/ambari-web/app/views/common/configs/service_configs_by_category_view.js
+++ b/ambari-web/app/views/common/configs/service_configs_by_category_view.js
@@ -25,7 +25,7 @@ App.ServiceConfigsByCategoryView = Em.View.extend(App.UserPref, App.ConfigOverri
 
   templateName: require('templates/common/configs/service_config_category'),
 
-  classNames: ['accordion-group', 'common-config-category'],
+  classNames: ['panel-group', 'common-config-category'],
 
   classNameBindings: ['category.name', 'isShowBlock::hidden'],
 
@@ -230,6 +230,7 @@ App.ServiceConfigsByCategoryView = Em.View.extend(App.UserPref, App.ConfigOverri
       var self = this;
       return App.ModalPopup.show({
         classNames: ['modal-690px-width'],
+        modalDialogClasses: ['modal-lg'],
         showCloseButton: false,
         header: "Warning: you must also change these Service properties",
         onApply: function () {
@@ -338,7 +339,7 @@ App.ServiceConfigsByCategoryView = Em.View.extend(App.UserPref, App.ConfigOverri
       }
       return className;
     });
-    var categoryBlock = $('.' + classNames.join('.') + '>.accordion-body');
+    var categoryBlock = $('.' + classNames.join('.') + '>.panel-body');
     this.get('category.isCollapsed') ? categoryBlock.hide() : categoryBlock.show();
   },
 
@@ -374,12 +375,12 @@ App.ServiceConfigsByCategoryView = Em.View.extend(App.UserPref, App.ConfigOverri
    * @method onToggleBlock
    */
   onToggleBlock: function () {
-    this.$('.accordion-body').toggle('blind', 500);
+    this.$('.panel-body').toggle('blind', 500);
     this.toggleProperty('category.isCollapsed');
   },
 
   /**
    * Determines should accordion be collapsed by default
    * @returns {boolean}
    * @method calcIsCollapsed
    */
@@ -515,7 +516,8 @@ App.ServiceConfigsByCategoryView = Em.View.extend(App.UserPref, App.ConfigOverri
     });
 
     App.ModalPopup.show({
-      classNames: ['sixty-percent-width-modal'],
+      classNames: ['common-modal-wrapper'],
+      modalDialogClasses: ['modal-lg'],
       header: Em.I18n.t('installer.step7.config.addProperty'),
       primary: Em.I18n.t('add'),
       secondary: Em.I18n.t('common.cancel'),
@@ -627,8 +629,8 @@ App.ServiceConfigsByCategoryView = Em.View.extend(App.UserPref, App.ConfigOverri
         },
         filterByKey: function (event) {
           var controller = (App.router.get('currentState.name') == 'configs')
-            ? App.router.get('mainServiceInfoConfigsController')
-            : App.router.get('wizardStep7Controller');
+              ? App.router.get('mainServiceInfoConfigsController')
+              : App.router.get('wizardStep7Controller');
           this.get('parentView').onClose();
           controller.set('filter', event.view.get('serviceConfigObj.name'));
         }

http://git-wip-us.apache.org/repos/asf/ambari/blob/2a77e39c/ambari-web/app/views/common/configs/widgets/checkbox_config_widget_view.js
----------------------------------------------------------------------
@@ -374,12 +375,12 @@ App.ServiceConfigsByCategoryView = Em.View.extend(App.UserPref, App.ConfigOverri
 
   /**
-   * Determines should accordion be collapsed by default
+   * Determines should panel be collapsed by default
    * @returns {boolean}
    * @method calcIsCollapsed